@@ -1,5 +1,5 @@
 package TreePath::Role::Graph;
-$TreePath::Role::Graph::VERSION = '0.02';
+$TreePath::Role::Graph::VERSION = '0.03';
 use Moose::Role;
 use MooseX::Types::Path::Class;
 use GraphViz2;
@@ -22,7 +22,7 @@ sub graph {
     my $var  = shift;
 
     my $g = GraphViz2->new();
-    foreach my $id ( sort { $a <=> $b } keys %{$self->tree}) {
+    foreach my $id ( sort { $a cmp $b } keys %{$self->tree}) {
 
         my $node   = $self->tree->{$id};
         my $parent = $node->{parent};
@@ -38,25 +38,22 @@ sub graph {
             $label_keys_children = "{$label_keys_children}|";
         }
 
-        my $position = '';
-        $position = " / pos:" . $node->{$self->_position_field}
-            if defined $node->{$self->_position_field};
-
         my $label = "{ $label_keys_children "
             . $node->{$self->_search_field}
-            . " (". $node->{$self->_type_field}
-            . "$position"
+            . " (". $node->{$self->_source_field}
             .")}";
 
         my $fg_color = 'black';
-        if ( defined $self->colors && defined $self->colors->{$node->{$self->_type_field}}) {
-            $fg_color = $self->colors->{$node->{$self->_type_field}}->{fg};
+        if ( defined $self->colors && defined $self->colors->{$node->{$self->_source_field}}) {
+            $fg_color = $self->colors->{$node->{$self->_source_field}}->{fg};
         }
-        $g->add_node( name => $node->{id}, label => $label, shape => 'record', color => $fg_color);
+        my $key_obj = $self->_key_obj($node);
+        $g->add_node( name => $key_obj, label => $label, shape => 'record', color => $fg_color);
 
         if ( $node->{parent} ){
             my $key_children = $self->_key_children($node, $parent);
-            $g->add_edge( from => $node->{id}, to => "$parent->{id}:_${key_children}_"  );
+            my $key_parent = $self->_key_obj($parent);
+            $g->add_edge( from => $key_obj, to => "$key_parent:_${key_children}_"  );
 
             }
     }
@@ -73,7 +70,7 @@ TreePath::Role::Graph - Role to visualize TreePath Graph
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -87,7 +84,7 @@ version 0.02
 
     use TPGraph;
 
-    my $colors_type = {
+    my $colors_source = {
                    'T1' => { fg => 'blue'},
                    'T2' => { fg => 'magenta'},
                    'T3' => { fg => 'brown'},
@@ -95,12 +92,10 @@ version 0.02
 
     # get tree from hash, dbix, file
     $tp = TPGraph->new(  conf   => $tree,
-                         colors => $colors_type,
+                         colors => $colors_source,
                          output => '/tmp/test.png' );
 
-    $tp->graph; # all the tree
-
-    $tp->graph($node);
+    $tp->graph;
 
 =head1 METHODS
 
